@@ -47,12 +47,15 @@ class Publish:
         print(sh.git("commit", "-a", "-m", "Bump version in pyproject.toml"))
         print(sh.git("push"))
         version = str(sh.poetry("version", "-s")).strip()
-        asset = str(sh.tail(sh.grep(sh.ls("-tr", "dist"), ".whl"),
+        asset = str(sh.tail(sh.grep(sh.ls("-1tr", "dist"), ".whl"),
                     "-n1")).strip()
-        previous_version = str(sh.git("describe", "--tags",
-                                      "--abbrev=0")).strip()
+        try:
+            previous_version_string = str(sh.git("describe", "--tags",
+                                                 "--abbrev=0")).strip() + ".."
+        except sh.ErrorReturnCode_128:
+            previous_version_string = ""
         changelog = sh.git("--no-pager", "log", "--no-color",
-                           f"{previous_version}..HEAD^", "--oneline",
+                           f"{previous_version_string}HEAD^", "--oneline",
                            "--no-decorate")
         print(sh.gh("release", "create", version, f"dist/{asset}",
                     "--notes", changelog))
